==> nextcloud-21.0.3.tgz: nextcloud/apps/files_sharing/l10n/da.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Delt med dig",
    "Nothing shared with you yet" : "Der deles ikke noget med dig endnu",
    "Files and folders others share with you will show up here" : "Filer og mapper som andre deler med dig, vil blive vist her",
    "Shared with others" : "Delt med andre",
    "Nothing shared yet" : "Der deles endnu ikke noget",
    "Files and folders you share will show up here" : "Filer og mapper som du deler, vil blive vist her",
    "Shared by link" : "Delt via link",
    "No shared links" : "Ingen delte link",
    "Files and folders you share by link will show up here" : "Filer og mapper som du deler gennem link, vil blive vist her",
    "Deleted shares" : "Slettede delinger",
    "No deleted shares" : "Ingen slettede delinger",
    "Shares you deleted will show up here" : "Delinger du har slettet vil dukke op her",
    "Pending shares" : "Afventende delinger",
    "No pending shares" : "Ingen afventende delinger",
    "Shares you have received but not confirmed will show up here" : "Delinger du har modtaget men ikke accepteret vil dukke op her",
    "Shares" : "Delinger",
    "No shares" : "Ingen delinger",
    "Shares will show up here" : "Delinger vil dukke op her",
    "Restore" : "Gendan",
    "Restore share" : "Gendan deling",
    "Something happened. Unable to restore the share." : "Der skete et eller andet. Ude af stand til at genskabe delingen.",
    "Accept share" : "Accepter deling",
    "Something happened. Unable to accept the share." : "Der skete et eller andet. Ude af stand til at acceptere delingen.",
    "Reject share" : "Afvis deling",
    "Something happened. Unable to reject the share." : "Der skete et eller andet. Ude af stand til at afvise delingen.",
    "error" : "fejl",
    "This will stop your current uploads." : "Dette vil stoppe din nuværende uploads.",
    "Move or copy" : "Flyt eller kopier",
    "Download" : "Hent",
    "Delete" : "Slet",
    "You can upload into this folder" : "Du kan overføre til denne mappe",
    "Terms of service" : "Servicebetingelser",
    "No compatible server found at {remote}" : "Ingen kompatible servere fundet på {remote}",
    "Invalid server URL" : "Ugyldig server adresse",
    "Failed to add the public link to your Nextcloud" : "Fejl ved tilføjelse af offentligt link til din Nextcloud",
    "No expiration date set" : "Ingen udløbsdato sat",
    "Shared by" : "Delt af",
    "File shares" : "Fildelinger",
    "Downloaded via public link" : "Downloaded via et offentligt link",
    "Downloaded by {email}" : "Downloaded af {email}",
    "{file} downloaded via public link" : "{file} downloaded via et offentligt link",
    "{email} downloaded {file}" : "{email} downloadede {file}",
    "Shared with group {group}" : "Delt med gruppe {group}",
    "Removed share for group {group}" : "Fjernede deling med gruppe {group}",
    "{actor} shared with group {group}" : "{actor} delte med gruppe {group}",
    "{actor} removed share for group {group}" : "{actor} fjernede deling fra gruppe {group}",
    "Share for group {group} expired" : "Deling med gruppe {group} udløbet",
    "You shared {file} with group {group}" : "Du delte {file} med gruppe {group}",
    "You removed group {group} from {file}" : "Du fjernede {group} fra {file}",
    "{actor} shared {file} with group {group}" : "{actor} delte {file} med gruppe {group}",
    "{actor} removed group {group} from {file}" : "{actor} fjernede {group} fra {file}",
    "Share for file {file} with group {group} expired" : "Deling af {file} med gruppe {group} udløbet",
    "Shared as public link" : "Delte som offentligt link",
    "Removed public link" : "Fjernede offentlige link",
    "Public link expired" : "Offentligt link er udløbet",
    "{actor} shared as public link" : "{actor} delt som offentligt link",
    "{actor} removed public link" : "{actor} fjernede offentligt link",
    "Public link of {actor} expired" : "Offentligt link fra {actor} udløbet",
    "You shared {file} as public link" : "Du har delt {file} som offentligt link",
    "You removed public link for {file}" : "Du fjernede offentligt link til {file}",
    "Public link expired for {file}" : "Offentligt link til {file} er udløbet",
    "{actor} shared {file} as public link" : "{actor} delte {file} med et offentligt link",
    "{actor} removed public link for {file}" : "{actor} fjernede offentlig link til {file}",
    "Public link of {actor} for {file} expired" : "Offentligt link fra {actor} for {file} er udløbet",
    "{user} accepted the remote share" : "{user} accepterede den afsides deling",
    "{user} declined the remote share" : "{user} afviste den afsides deling",
    "You received a new remote share {file} from {user}" : "Du modtog en ny ekstern deling til {file} fra {user}",
    "{user} accepted the remote share of {file}" : "{user} accepterede den afsides deling af {file}",
    "{user} declined the remote share of {file}" : "{user} afviste den afsides deling af {file}",
    "{user} unshared {file} from you" : " {user} stoppede deling af {file} med dig",
    "Shared with {user}" : "Delt med  {user}",
    "Removed share for {user}" : "Fjernede deling med {user}",
    "You removed yourself" : "Du fjernede dig selv",
    "{actor} removed themselves" : "{actor} fjernede dem selv",
    "{actor} shared with {user}" : "{actor} delte med {user}",
    "{actor} removed share for {user}" : "{actor} fjernede deling med {user}",
    "Shared by {actor}" : "Delt af {actor}",
    "{actor} removed share" : "{actor} fjernede deling",
    "Share for {user} expired" : "Deling med {user} udløbet",
    "Share expired" : "Deling udløbet",
    "You shared {file} with {user}" : "Du delte {file} med gruppe {user}",
    "You removed {user} from {file}" : "Du fjernede {user} fra {file}",
    "You removed yourself from {file}" : "Du fjernede dig selv fra {file}",
    "{actor} removed themselves from {file}" : "{actor} fjernede dem selv fra {file}",
    "{actor} shared {file} with {user}" : "{actor} delte {file} med {user}",
    "{actor} removed {user} from {file}" : "{actor} fjernede {user} fra {file}",
    "{actor} shared {file} with you" : "{actor} delte {file} med dig",
    "{actor} removed you from the share named {file}" : "{actor} fjernede dig fra delingen af {file}",
    "Share for file {file} with {user} expired" : "Deling af {file} med {user} udløbet",
    "Share for file {file} expired" : "Deling af {file} udløbet",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "En fil eller mapper delt vie mail eller offentligt link blev <strong>downloaded</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "En fil eller mappe blev delt fra <strong>en anden server</strong>",
    "Files" : "Filer",
    "A file or folder has been <strong>shared</strong>" : "En fil eller mappe er blevet <strong>delt</strong>",
    "Shared link" : "Delt link",
    "Wrong share ID, share doesn't exist" : "Forkert DelingsID, deling findes ikke",
    "Could not delete share" : "Kunne ikke slette deling",
    "Please specify a file or folder path" : "Præciser venligst en fil eller mappesti",
    "Wrong path, file/folder doesn't exist" : "Forkert sti, fil/mappe findes ikke",
    "Please specify a valid user" : "Angiv en gyldig bruger",
    "Group sharing is disabled by the administrator" : "Gruppedeling er deaktiveret af administratoren",
    "Please specify a valid group" : "Angiv en gyldig gruppe",
    "Public link sharing is disabled by the administrator" : "Deling med offentligt link er deaktiveret af administratoren",
    "Public upload disabled by the administrator" : "Offentlige uploads er slået fra af administratoren",
    "Public upload is only possible for publicly shared folders" : "Offentligt upload er kun muligt i mapper der er delt offentligt",
    "Invalid date, date format must be YYYY-MM-DD" : "Ugyldig dato. Brug formatet ÅÅÅ-MM-DD",
    "Not a directory" : "Ikke en mappe",
    "Could not lock path" : "Stien kunne ikke låses",
    "Wrong or no update parameter given" : "Forkert eller manglende opdateringsparameter",
    "shared by %s" : "deles af %s",
    "Direct link" : "Direkte link",
    "Share API is disabled" : "Delings-API er slået fra",
    "File sharing" : "Fildeling",
    "Accept" : "Accepter",
    "Reject" : "Afvis",
    "Sharing" : "Deling",
    "Allow editing" : "Tillad redigering",
    "Allow resharing" : "Tillad videredeling",
    "Expiration date enforced" : "Udløbsdato tvungen",
    "Set expiration date" : "Angiv udløbsdato",
    "Note to recipient" : "Note til modtager",
    "Unshare" : "Fjern deling",
    "group" : "gruppe",
    "conversation" : "samtale",
    "remote" : "ekstern",
    "remote group" : "ekstern gruppe",
    "guest" : "Gæst",
    "Internal link" : "Internt link",
    "Link copied" : "Link kopieret",
    "Copy to clipboard" : "Kopier til udklipsholder",
    "Only works for users with access to this folder" : "Virker kun for brugere med adgang til denne folder",
    "Only works for users with access to this file" : "Virker kun for brugere med adgang til denne fil",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Cancel" : "Annullér",
    "Read only" : "Skrivebeskyttet",
    "Allow upload and editing" : "Tillad upload og redigering",
    "File drop (upload only)" : "Fil drop (kun upload)",
    "Hide download" : "Skjul download",
    "Password protect" : "Beskyt med adgangskode",
    "Add another link" : "Tilføj et link mere",
    "Create a new share link" : "Opret et nyt delingslink",
    "Share link" : "Share link",
    "Resharing is not allowed" : "Gendeling er ikke tilladt",
    "Searching …" : "Søger ...",
    "Search globally" : "Søg globalt",
    "Others with access" : "Andre med adgang",
    "No other users with access found" : "Ingen andre brugere med adgang fundet",
    "Toggle list of others with access to this directory" : "Vis/skjul liste over andre med adgang til denne mappe",
    "Toggle list of others with access to this file" : "Vis/skjul liste over andre med adgang til denne fil",
    "Shared" : "Delt",
    "Share" : "Del",
    "Shared with" : "Delt med",
    "Shared with you and the group {group} by {owner}" : "Delt med dig og grupp {group} af {owner}",
    "Shared with you and {circle} by {owner}" : "Delt med dig og {circle} af {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "Delt med dig og konversationen {conversation} af {owner}",
    "Shared with you in a conversation by {owner}" : "Delt med dig og konversationen af {owner}",
    "Shared with you by {owner}" : "Delt med dig {owner}",
    "No entries found in this folder" : "Der blev ikke fundet poster i denne mappe",
    "Name" : "Navn",
    "Share time" : "Dele periode",
    "Expiration date" : "Udløbsdato",
    "Sorry, this link doesn’t seem to work anymore." : "Desværre, dette link ser ikke ud til at fungerer længere.",
    "Reasons might be:" : "Årsagen kan være:",
    "the item was removed" : "Filen blev fjernet",
    "the link expired" : "linket udløb",
    "sharing is disabled" : "deling er deaktiveret",
    "For more info, please ask the person who sent this link." : "For yderligere information, kontakt venligst personen der sendte linket. ",
    "Share note" : "Del note",
    "Toggle grid view" : "Vis som liste",
    "Download %s" : "Hent %s",
    "Upload files to %s" : "Upload filer til %s",
    "Note" : "Note",
    "Select or drop files" : "Vælg eller slip filer",
    "Uploaded files:" : "Uploadede filer:",
    "Add to your Nextcloud" : "Tilføj til din Nextcloud",
    "invalid permissions" : "Ugyldige rettigheder"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-22.2.3.tgz: nextcloud/apps/files_sharing/l10n/da.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Delt med dig",
    "Nothing shared with you yet" : "Der deles ikke noget med dig endnu",
    "Files and folders others share with you will show up here" : "Filer og mapper som andre deler med dig, vil blive vist her",
    "Shared with others" : "Delt med andre",
    "Nothing shared yet" : "Der deles endnu ikke noget",
    "Files and folders you share will show up here" : "Filer og mapper som du deler, vil blive vist her",
    "Shared by link" : "Delt via link",
    "No shared links" : "Ingen delte link",
    "Files and folders you share by link will show up here" : "Filer og mapper som du deler gennem link, vil blive vist her",
    "Deleted shares" : "Slettede delinger",
    "No deleted shares" : "Ingen slettede delinger",
    "Shares you deleted will show up here" : "Delinger du har slettet vil dukke op her",
    "Pending shares" : "Afventende delinger",
    "No pending shares" : "Ingen afventende delinger",
    "Shares you have received but not confirmed will show up here" : "Delinger du har modtaget men ikke accepteret vil dukke op her",
    "Shares" : "Delinger",
    "No shares" : "Ingen delinger",
    "Shares will show up here" : "Delinger vil dukke op her",
    "Restore" : "Gendan",
    "Restore share" : "Gendan deling",
    "Something happened. Unable to restore the share." : "Der skete et eller andet. Ude af stand til at genskabe delingen.",
    "Accept share" : "Accepter deling",
    "Something happened. Unable to accept the share." : "Der skete et eller andet. Ude af stand til at acceptere delingen.",
    "Reject share" : "Afvis deling",
    "Something happened. Unable to reject the share." : "Der skete et eller andet. Ude af stand til at afvise delingen.",
    "error" : "fejl",
    "This will stop your current uploads." : "Dette vil stoppe din nuværende uploads.",
    "Move or copy" : "Flyt eller kopier",
    "Download" : "Hent",
    "Delete" : "Slet",
    "You can upload into this folder" : "Du kan overføre til denne mappe",
    "Terms of service" : "Servicebetingelser",
    "No compatible server found at {remote}" : "Ingen kompatible servere fundet på {remote}",
    "Invalid server URL" : "Ugyldig server adresse",
    "Failed to add the public link to your Nextcloud" : "Fejl ved tilføjelse af offentligt link til din Nextcloud",
    "No expiration date set" : "Ingen udløbsdato sat",
    "Shared by" : "Delt af",
    "File shares" : "Fildelinger",
    "Downloaded via public link" : "Downloaded via et offentligt link",
    "Downloaded by {email}" : "Downloaded af {email}",
    "{file} downloaded via public link" : "{file} downloaded via et offentligt link",
    "{email} downloaded {file}" : "{email} downloadede {file}",
    "Shared with group {group}" : "Delt med gruppe {group}",
    "Removed share for group {group}" : "Fjernede deling med gruppe {group}",
    "{actor} shared with group {group}" : "{actor} delte med gruppe {group}",
    "{actor} removed share for group {group}" : "{actor} fjernede deling fra gruppe {group}",
    "Share for group {group} expired" : "Deling med gruppe {group} udløbet",
    "You shared {file} with group {group}" : "Du delte {file} med gruppe {group}",
    "You removed group {group} from {file}" : "Du fjernede {group} fra {file}",
    "{actor} shared {file} with group {group}" : "{actor} delte {file} med gruppe {group}",
    "{actor} removed group {group} from {file}" : "{actor} fjernede {group} fra {file}",
    "Share for file {file} with group {group} expired" : "Deling af {file} med gruppe {group} udløbet",
    "Shared as public link" : "Delte som offentligt link",
    "Removed public link" : "Fjernede offentlige link",
    "Public link expired" : "Offentligt link er udløbet",
    "{actor} shared as public link" : "{actor} delt som offentligt link",
    "{actor} removed public link" : "{actor} fjernede offentligt link",
    "Public link of {actor} expired" : "Offentligt link fra {actor} udløbet",
    "You shared {file} as public link" : "Du har delt {file} som offentligt link",
    "You removed public link for {file}" : "Du fjernede offentligt link til {file}",
    "Public link expired for {file}" : "Offentligt link til {file} er udløbet",
    "{actor} shared {file} as public link" : "{actor} delte {file} med et offentligt link",
    "{actor} removed public link for {file}" : "{actor} fjernede offentlig link til {file}",
    "Public link of {actor} for {file} expired" : "Offentligt link fra {actor} for {file} er udløbet",
    "{user} accepted the remote share" : "{user} accepterede den afsides deling",
    "{user} declined the remote share" : "{user} afviste den afsides deling",
    "You received a new remote share {file} from {user}" : "Du modtog en ny ekstern deling til {file} fra {user}",
    "{user} accepted the remote share of {file}" : "{user} accepterede den afsides deling af {file}",
    "{user} declined the remote share of {file}" : "{user} afviste den afsides deling af {file}",
    "{user} unshared {file} from you" : " {user} stoppede deling af {file} med dig",
    "Shared with {user}" : "Delt med  {user}",
    "Removed share for {user}" : "Fjernede deling med {user}",
    "You removed yourself" : "Du fjernede dig selv",
    "{actor} removed themselves" : "{actor} fjernede dem selv",
    "{actor} shared with {user}" : "{actor} delte med {user}",
    "{actor} removed share for {user}" : "{actor} fjernede deling med {user}",
    "Shared by {actor}" : "Delt af {actor}",
    "{actor} removed share" : "{actor} fjernede deling",
    "Share for {user} expired" : "Deling med {user} udløbet",
    "Share expired" : "Deling udløbet",
    "You shared {file} with {user}" : "Du delte {file} med gruppe {user}",
    "You removed {user} from {file}" : "Du fjernede {user} fra {file}",
    "You removed yourself from {file}" : "Du fjernede dig selv fra {file}",
    "{actor} removed themselves from {file}" : "{actor} fjernede dem selv fra {file}",
    "{actor} shared {file} with {user}" : "{actor} delte {file} med {user}",
    "{actor} removed {user} from {file}" : "{actor} fjernede {user} fra {file}",
    "{actor} shared {file} with you" : "{actor} delte {file} med dig",
    "{actor} removed you from the share named {file}" : "{actor} fjernede dig fra delingen af {file}",
    "Share for file {file} with {user} expired" : "Deling af {file} med {user} udløbet",
    "Share for file {file} expired" : "Deling af {file} udløbet",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "En fil eller mapper delt vie mail eller offentligt link blev <strong>downloaded</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "En fil eller mappe blev delt fra <strong>en anden server</strong>",
    "Files" : "Filer",
    "A file or folder has been <strong>shared</strong>" : "En fil eller mappe er blevet <strong>delt</strong>",
    "Shared link" : "Delt link",
    "Wrong share ID, share doesn't exist" : "Forkert DelingsID, deling findes ikke",
    "Could not delete share" : "Kunne ikke slette deling",
    "Please specify a file or folder path" : "Præciser venligst en fil eller mappesti",
    "Wrong path, file/folder doesn't exist" : "Forkert sti, fil/mappe findes ikke",
    "Please specify a valid user" : "Angiv en gyldig bruger",
    "Group sharing is disabled by the administrator" : "Gruppedeling er deaktiveret af administratoren",
    "Please specify a valid group" : "Angiv en gyldig gruppe",
    "Public link sharing is disabled by the administrator" : "Deling med offentligt link er deaktiveret af administratoren",
    "Public upload disabled by the administrator" : "Offentlige uploads er slået fra af administratoren",
    "Public upload is only possible for publicly shared folders" : "Offentligt upload er kun muligt i mapper der er delt offentligt",
    "Invalid date, date format must be YYYY-MM-DD" : "Ugyldig dato. Brug formatet ÅÅÅ-MM-DD",
    "Not a directory" : "Ikke en mappe",
    "Could not lock path" : "Stien kunne ikke låses",
    "Wrong or no update parameter given" : "Forkert eller manglende opdateringsparameter",
    "shared by %s" : "deles af %s",
    "Direct link" : "Direkte link",
    "Share API is disabled" : "Delings-API er slået fra",
    "File sharing" : "Fildeling",
    "Accept" : "Accepter",
    "Reject" : "Afvis",
    "Sharing" : "Deling",
    "Allow editing" : "Tillad redigering",
    "Allow resharing" : "Tillad videredeling",
    "Expiration date enforced" : "Udløbsdato tvungen",
    "Set expiration date" : "Angiv udløbsdato",
    "Note to recipient" : "Note til modtager",
    "Unshare" : "Fjern deling",
    "group" : "gruppe",
    "conversation" : "samtale",
    "remote" : "ekstern",
    "remote group" : "ekstern gruppe",
    "guest" : "Gæst",
    "Internal link" : "Internt link",
    "Link copied" : "Link kopieret",
    "Copy to clipboard" : "Kopier til udklipsholder",
    "Only works for users with access to this folder" : "Virker kun for brugere med adgang til denne folder",
    "Only works for users with access to this file" : "Virker kun for brugere med adgang til denne fil",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Cancel" : "Annullér",
    "Read only" : "Skrivebeskyttet",
    "Allow upload and editing" : "Tillad upload og redigering",
    "File drop (upload only)" : "Fil drop (kun upload)",
    "Hide download" : "Skjul download",
    "Password protect" : "Beskyt med adgangskode",
    "Add another link" : "Tilføj et link mere",
    "Create a new share link" : "Opret et nyt delingslink",
    "Share link" : "Share link",
    "Resharing is not allowed" : "Gendeling er ikke tilladt",
    "Searching …" : "Søger ...",
    "Search globally" : "Søg globalt",
    "Others with access" : "Andre med adgang",
    "No other users with access found" : "Ingen andre brugere med adgang fundet",
    "Toggle list of others with access to this directory" : "Vis/skjul liste over andre med adgang til denne mappe",
    "Toggle list of others with access to this file" : "Vis/skjul liste over andre med adgang til denne fil",
    "Shared" : "Delt",
    "Share" : "Del",
    "Shared with" : "Delt med",
    "Shared with you and the group {group} by {owner}" : "Delt med dig og grupp {group} af {owner}",
    "Shared with you and {circle} by {owner}" : "Delt med dig og {circle} af {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "Delt med dig og konversationen {conversation} af {owner}",
    "Shared with you in a conversation by {owner}" : "Delt med dig og konversationen af {owner}",
    "Shared with you by {owner}" : "Delt med dig {owner}",
    "No entries found in this folder" : "Der blev ikke fundet poster i denne mappe",
    "Name" : "Navn",
    "Share time" : "Dele periode",
    "Expiration date" : "Udløbsdato",
    "Sorry, this link doesn’t seem to work anymore." : "Desværre, dette link ser ikke ud til at fungerer længere.",
    "Reasons might be:" : "Årsagen kan være:",
    "the item was removed" : "Filen blev fjernet",
    "the link expired" : "linket udløb",
    "sharing is disabled" : "deling er deaktiveret",
    "For more info, please ask the person who sent this link." : "For yderligere information, kontakt venligst personen der sendte linket. ",
    "Share note" : "Del note",
    "Toggle grid view" : "Vis som liste",
    "Upload files to %s" : "Upload filer til %s",
    "Note" : "Note",
    "Select or drop files" : "Vælg eller slip filer",
    "Uploaded files:" : "Uploadede filer:",
    "Add to your Nextcloud" : "Tilføj til din Nextcloud",
    "invalid permissions" : "Ugyldige rettigheder",
    "Download %s" : "Hent %s"
},
"nplurals=2; plural=(n != 1);");
